@@ -7,9 +7,6 @@
 
 G_BEGIN_DECLS
 
-void go_plugin_init	(GOPlugin *p, GOCmdContext *cc); /* optional, called after dlopen */
-void go_plugin_shutdown	(GOPlugin *p, GOCmdContext *cc); /* optional, called before close */
-
 typedef struct {
 	char const * const key;		/* object being versioned */
 	char const * const version;	/* version id (strict equality is required) */
@@ -34,6 +31,12 @@ G_MODULE_EXPORT GOPluginModuleDepend const go_plugin_depends [] = {	\
 G_MODULE_EXPORT GOPluginModuleHeader const go_plugin_header =  		\
 	{ GOFFICE_MODULE_PLUGIN_MAGIC_NUMBER, G_N_ELEMENTS (go_plugin_depends) }
 
+/* the folowwing two functions ar declared here, but are not
+ * implemented in libgoffice. Each plugin must implement one
+ * instance of both. */
+void go_plugin_init (GOPlugin *plugin, GOCmdContext *cc);
+void go_plugin_shutdown (GOPlugin *plugin, GOCmdContext *cc);
+
 G_END_DECLS
 
 #endif /* GOFFICE_MODULE_PLUGIN_DEFS_H */
