@@ -15,7 +15,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301
  * USA
  */
 
@@ -42,7 +42,7 @@ gog_pie_series_element_pref (GogPieSeriesElement *element, GOCmdContext *cc)
 	char const *dir = go_plugin_get_dir_name (
 		go_plugins_get_plugin_by_id ("GOffice_plot_pie"));
 	char	 *path = g_build_filename (dir, "gog-pie-series.glade", NULL);
-	GladeXML *gui = go_libglade_new (path, "gog_pie_series_element_prefs", NULL, cc);
+	GladeXML *gui = go_libglade_new (path, "gog_pie_series_element_prefs", GETTEXT_PACKAGE, cc);
 
 	g_free (path);
         if (gui == NULL)
@@ -115,7 +115,7 @@ gog_pie_plot_pref (GogPiePlot *pie, GOCmdContext *cc)
 	char const *dir = go_plugin_get_dir_name (
 		go_plugins_get_plugin_by_id ("GOffice_plot_pie"));
 	char	 *path = g_build_filename (dir, "gog-pie-prefs.glade", NULL);
-	GladeXML *gui = go_libglade_new (path, "gog_pie_prefs", NULL, cc);
+	GladeXML *gui = go_libglade_new (path, "gog_pie_prefs", GETTEXT_PACKAGE, cc);
 
 	g_free (path);
         if (gui == NULL)
@@ -148,7 +148,7 @@ gog_ring_plot_pref (GogRingPlot *ring, GOCmdContext *cc)
 	char const *dir = go_plugin_get_dir_name (
 		go_plugins_get_plugin_by_id ("GOffice_plot_pie"));
 	char	 *path = g_build_filename (dir, "gog-ring-prefs.glade", NULL);
-	GladeXML *gui = go_libglade_new (path, "gog_ring_prefs", NULL, cc);
+	GladeXML *gui = go_libglade_new (path, "gog_ring_prefs", GETTEXT_PACKAGE, cc);
 
 	g_free (path);
         if (gui == NULL)
@@ -186,7 +186,7 @@ gog_pie_series_pref (GogPieSeries *pie, GOCmdContext *cc)
 	char const *dir = go_plugin_get_dir_name (
 		go_plugins_get_plugin_by_id ("GOffice_plot_pie"));
 	char	 *path = g_build_filename (dir, "gog-pie-prefs.glade", NULL);
-	GladeXML *gui = go_libglade_new (path, "gog_pie_prefs", NULL, cc);
+	GladeXML *gui = go_libglade_new (path, "gog_pie_prefs", GETTEXT_PACKAGE, cc);
 
 	g_free (path);
         if (gui == NULL)
